// Macros useful for testing.
#[macro_use]
mod macros;

// Utilities for making tests easier to write.
mod util;

// Tests themselves.
mod test_config;
mod test_hook;
mod test_signature;
